==> cell_tracking_bc-2022.30-py3-none-any.whl: cell_tracking_BC/type/analysis.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import dataclasses as dtcl
from typing import Any, Dict, Tuple

from cell_tracking_BC.type.acquisition.frame import all_versions_h
from cell_tracking_BC.type.segmentation.sequence import AllSegmentations, segmentations_t
from cell_tracking_BC.type.acquisition.sequence import AllChannels, sequence_t
from cell_tracking_BC.type.track.multiple.structured import tracks_t


@dtcl.dataclass(repr=False, eq=False)
class analysis_t:
    parameter_file: str = None
    parameters: Dict[str, Any] = None
    sequence: sequence_t = None
    segmentations: segmentations_t = None
    tracks: tracks_t = None


def AllStreams(analysis: analysis_t, /) -> Tuple[all_versions_h, str]:
    """"""
    all_streams, current_stream = AllChannels(analysis.sequence)
    all_versions, _ = AllSegmentations(analysis.segmentations)

    all_streams.update(all_versions)

    return all_streams, current_stream

==> cell_tracking_bc-2023.2-py3-none-any.whl: cell_tracking_BC/type/analysis.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import dataclasses as dtcl
from typing import Any, Dict

from cell_tracking_BC.type.segmentation.sequence import segmentations_t
from cell_tracking_BC.type.acquisition.sequence import sequence_t
from cell_tracking_BC.type.track.multiple.structured import tracks_t


@dtcl.dataclass(repr=False, eq=False)
class analysis_t:
    parameter_file: str = None
    parameters: Dict[str, Any] = None
    sequence: sequence_t = None
    segmentations: segmentations_t = None
    tracks: tracks_t = None
